% Auto-generated chapter 28 for muslim
% Hadiths in this chapter: 56

\hadithdefcmd{muslim}{4342}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ بُشَيْرِ، بْنِ يَسَارٍ عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، - قَالَ يَحْيَى وَحَسِبْتُ قَالَ - وَعَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّهُمَا قَالاَ خَرَجَ عَبْدُ اللَّهِ بْنُ سَهْلِ بْنِ زَيْدٍ وَمُحَيِّصَةُ بْنُ مَسْعُودِ بْنِ زَيْدٍ حَتَّى إِذَا كَانَا بِخَيْبَرَ تَفَرَّقَا فِي بَعْضِ مَا هُنَالِكَ ثُمَّ إِذَا مُحَيِّصَةُ يَجِدُ عَبْدَ اللَّهِ بْنَ سَهْلٍ قَتِيلاً فَدَفَنَهُ ثُمَّ أَقْبَلَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم هُوَ وَحُوَيِّصَةُ بْنُ مَسْعُودٍ وَعَبْدُ الرَّحْمَنِ بْنُ سَهْلٍ وَكَانَ أَصْغَرَ الْقَوْمِ فَذَهَبَ عَبْدُ الرَّحْمَنِ لِيَتَكَلَّمَ قَبْلَ صَاحِبَيْهِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَبِّرِ ‏"‏ ‏.‏ الْكُبْرَ فِي السِّنِّ فَصَمَتَ فَتَكَلَّمَ صَاحِبَاهُ وَتَكَلَّمَ مَعَهُمَا فَذَكَرُوا لِرَسُولِ اللَّهِ صلى الله عليه وسلم مَقْتَلَ عَبْدِ اللَّهِ بْنِ سَهْلٍ فَقَالَ لَهُمْ ‏"‏ أَتَحْلِفُونَ خَمْسِينَ يَمِينًا فَتَسْتَحِقُّونَ صَاحِبَكُمْ ‏"‏ ‏.‏ أَوْ ‏"‏ قَاتِلَكُمْ ‏"‏ ‏.‏ قَالُوا وَكَيْفَ نَحْلِفُ وَلَمْ نَشْهَدْ قَالَ ‏"‏ فَتُبْرِئُكُمْ يَهُودُ بِخَمْسِينَ يَمِينًا ‏"‏ ‏.‏ قَالُوا وَكَيْفَ نَقْبَلُ أَيْمَانَ قَوْمٍ كُفَّارٍ فَلَمَّا رَأَى ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَعْطَى عَقْلَهُ ‏.‏\hadithno{4342}\hadithtrans{Sahl b. Abu Hathma and Rafi' b. Khadij reported that 'Abdullah b. Sahl b. Zaid and Muhayyisa b. Mas'ud b. Zaid went out and as they reached Khaibar they were separated. Then Muhayyisa found 'Abdullah b. Sahl having been killed. He buried him, and then came to Allah's Messenger (ﷺ). They were Huwayyisa b. Mas'ud and 'Abd al-Rahman b. Sahl, and he (the latter one) was the youngest of the people (those three who had come to seek an interview with the Holy Prophet) began to talk before his Companions (had spoken). Thereupon Allah's Messenger (ﷺ) said:The eldest one (eldest in regard to age should speak). So he kept quiet, and his companions (Muhayyisa and Huwayyisa) began to speak, and he ('Abd al Rahman) spoke along with them and they narrated to Allah's Messenger (ﷺ) the murder of 'Abdullah b. Sahl. Thereupon he said to them: Are you prepared to take fifty oaths so that you may be entitled (to blood-wit) of your companion (or your man who has murdered)? They said: How can we take an oath on a matter which we have not witnessed? He (the Holy Prophet) said: Then the Jews will exonerate themselves by fifty oaths. They said: How can we accept the oaths of people who are unbelievers? When Allah's Messenger (ﷺ) saw that, he himself paid his blood-wit}}
\hadithdefcmd{muslim}{4343}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، وَرَافِعِ بْنِ خَدِيجٍ، أَنَّ مُحَيِّصَةَ بْنَ مَسْعُودٍ، وَعَبْدَ، اللَّهِ بْنَ سَهْلٍ انْطَلَقَا قِبَلَ خَيْبَرَ فَتَفَرَّقَا فِي النَّخْلِ فَقُتِلَ عَبْدُ اللَّهِ بْنُ سَهْلٍ فَاتَّهَمُوا الْيَهُودَ فَجَاءَ أَخُوهُ عَبْدُ الرَّحْمَنِ وَابْنَا عَمِّهِ حُوَيِّصَةُ وَمُحَيِّصَةُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَتَكَلَّمَ عَبْدُ الرَّحْمَنِ فِي أَمْرِ أَخِيهِ وَهُوَ أَصْغَرُ مِنْهُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَبِّرِ الْكُبْرَ - أَوْ قَالَ - لِيَبْدَإِ الأَكْبَرُ ‏"‏ ‏.‏ فَتَكَلَّمَا فِي أَمْرِ صَاحِبِهِمَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُقْسِمُ خَمْسُونَ مِنْكُمْ عَلَى رَجُلٍ مِنْهُمْ فَيُدْفَعُ بِرُمَّتِهِ ‏"‏ ‏.‏ قَالُوا أَمْرٌ لَمْ نَشْهَدْهُ كَيْفَ نَحْلِفُ قَالَ ‏"‏ فَتُبْرِئُكُمْ يَهُودُ بِأَيْمَانِ خَمْسِينَ مِنْهُمْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ قَوْمٌ كُفَّارٌ قَالَ فَوَدَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ قِبَلِهِ ‏.‏ قَالَ سَهْلٌ فَدَخَلْتُ مِرْبَدًا لَهُمْ يَوْمًا فَرَكَضَتْنِي نَاقَةٌ مِنْ تِلْكَ الإِبِلِ رَكْضَةً بِرِجْلِهَا ‏.‏ قَالَ حَمَّادٌ هَذَا أَوْ نَحْوَهُ ‏.‏\hadithno{4343}\hadithtrans{Sahl. b. Abu Hathma and Rafi' b. Khadij reported that Muhayyisa b. Mas'ud and 'Abdullah b. Sahl went towards Khaibar and they separated near the palm-trees. 'Abdullah b. Sahl was killed. They accused the Jews (for this act). And there came to Allah's Apostle (ﷺ) his brother (the brother of the slain person) 'Abd al-Rahman and his cousins Huwayyisa and Muhayyisa; and 'Abd al-Rahman talked to him about the matter pertaining to (the murder of) his brother, and he was the youngest among them. Thereupon Allah's Messenger (ﷺ) said:Show regard for the greatness of the old, or he said: Let the eldest begin speaking. Then they (Huwayyisa and Muhayyisa) spoke about the matter of their companion (murder of their cousin, 'Abdullah b. Sahl). Thereupon Allah's Messenger (ﷺ) said: Let fifty (persons) among you take oath for levelling the charge (of murder) against a person amongst them, and he would be surrendered to you. They said: We have not witnessed this matter ourselves. How can we then take oath? He (the Holy Prophet) said: The Jews will exonerate themselves by the oaths of fifty of them. They said: Messenger of Allah, they are non-believing people. Thereupon Allah's Messenger (ﷺ) paid the blood wit for him. Sahl said: As one day I entered the fold a she-camel amongst those camels hit me with its leg}}
\hadithdefcmd{muslim}{4344}{وَحَدَّثَنَا الْقَوَارِيرِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ، يَسَارٍ عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ نَحْوَهُ ‏.‏ وَقَالَ فِي حَدِيثِهِ فَعَقَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عِنْدِهِ ‏.‏ وَلَمْ يَقُلْ فِي حَدِيثِهِ فَرَكَضَتْنِي نَاقَةٌ ‏.‏\hadithno{4344}\hadithtrans{Sahl b. Abu Hathma has narrated this hadith through another chain of transmitters with a slight variation of words, but no mention has been made of the hitting by the she-camel}}
\hadithdefcmd{muslim}{4345}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي الثَّقَفِيَّ - جَمِيعًا عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سَهْلِ، بْنِ أَبِي حَثْمَةَ بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{4345}\hadithtrans{This hadith has been narrated on the authority of Sahl b. Abu Hathma through another chain of transmitters}}
\hadithdefcmd{muslim}{4346}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، أَنَّ عَبْدَ اللَّهِ بْنَ سَهْلِ بْنِ زَيْدٍ، وَمُحَيِّصَةَ بْنَ مَسْعُودِ بْنِ زَيْدٍ الأَنْصَارِيَّيْنِ، ثُمَّ مِنْ بَنِي حَارِثَةَ خَرَجَا إِلَى خَيْبَرَ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهِيَ يَوْمَئِذٍ صُلْحٌ وَأَهْلُهَا يَهُودُ فَتَفَرَّقَا لِحَاجَتِهِمَا فَقُتِلَ عَبْدُ اللَّهِ بْنُ سَهْلٍ فَوُجِدَ فِي شَرَبَةٍ مَقْتُولاً فَدَفَنَهُ صَاحِبُهُ ثُمَّ أَقْبَلَ إِلَى الْمَدِينَةِ فَمَشَى أَخُو الْمَقْتُولِ عَبْدُ الرَّحْمَنِ بْنُ سَهْلٍ وَمُحَيِّصَةُ وَحُوَيِّصَةُ فَذَكَرُوا لِرَسُولِ اللَّهِ صلى الله عليه وسلم شَأْنَ عَبْدِ اللَّهِ وَحَيْثُ قُتِلَ فَزَعَمَ بُشَيْرٌ وَهُوَ يُحَدِّثُ عَمَّنْ أَدْرَكَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ لَهُمْ ‏"‏ تَحْلِفُونَ خَمْسِينَ يَمِينًا وَتَسْتَحِقُّونَ قَاتِلَكُمْ ‏"‏ ‏.‏ أَوْ ‏"‏ صَاحِبَكُمْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَا شَهِدْنَا وَلاَ حَضَرْنَا ‏.‏ فَزَعَمَ أَنَّهُ قَالَ ‏"‏ فَتُبْرِئُكُمْ يَهُودُ بِخَمْسِينَ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ كَيْفَ نَقْبَلُ أَيْمَانَ قَوْمٍ كُفَّارٍ فَزَعَمَ بُشَيْرٌ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَقَلَهُ مِنْ عِنْدِهِ ‏.‏\hadithno{4346}\hadithtrans{Bushair b. Yasar reported that 'Abdullah b. Sahl b. Zaid and Muhayyisa b. Mas'ud b. Zaid, both of them were Ansar belonging to the tribe of Banu Haritha, set out to Khaibar during the lifetime of Allah's Messenger (ﷺ). There was peace during those days and (this place) was inhabited by the Jews. They parted company for their (respective) needs. 'Abdullab b. Sahl was killed, and his dead body was found in a tank. His companion (Muhayyisa) buried him and came to Medina, and the brothers of the slain 'Abd al-Rahman b. Sahl. and Muhayyisa and Huwayyisa told Allah's Messenger (ﷺ) the case of 'Abdullah and the place where he had been murdered. Bushair reported on the authority of one who had seen Allah's Messenger (ﷺ) that he had said to them:You take fifty oaths and you are entitled to blood-wit of (one) slain among you (or your companion). They said: Messenger of Allah, we neither saw (with our own eyes this murder) nor were we present there. Thereupon (Allah's Messenger is reported to have said): Then the Jews will exonerate themselves by taking fifty oaths. They said: Allah's Messenger, how can we accept the oath of unbelieving people? Bushair said that Allah's Messenger (ﷺ) paid the blood-wit himself}}
\hadithdefcmd{muslim}{4347}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ مِنْ بَنِي حَارِثَةَ يُقَالُ لَهُ عَبْدُ اللَّهِ بْنُ سَهْلِ بْنِ زَيْدٍ انْطَلَقَ هُوَ وَابْنُ عَمٍّ لَهُ يُقَالُ لَهُ مُحَيِّصَةُ بْنُ مَسْعُودِ بْنِ زَيْدٍ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ اللَّيْثِ إِلَى قَوْلِهِ فَوَدَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عِنْدِهِ ‏.‏ قَالَ يَحْيَى فَحَدَّثَنِي بُشَيْرُ بْنُ يَسَارٍ قَالَ أَخْبَرَنِي سَهْلُ بْنُ أَبِي حَثْمَةَ قَالَ لَقَدْ رَكَضَتْنِي فَرِيضَةٌ مِنْ تِلْكَ الْفَرَائِضِ بِالْمِرْبَدِ ‏.‏\hadithno{4347}\hadithtrans{Bushair b. Yasar reported that a person from the Ansar belonging to the tribe of Banu Haritha who was called 'Abdullah b. Sahl b. Zaid set out and the son of his uncle called Muhayyisa b. Mas'ud b. Zaid, the rest of the hadith is the same up to the words:" Allah's Messenger (ﷺ) paid the blood-wit himself." Bushair b. Yasar reported that Sahl b. Abu Hathma said: One camel amongst the camels paid as blood-wit kicked me while I was in the (camel) enclosure}}
\hadithdefcmd{muslim}{4348}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدٍ، حَدَّثَنَا بُشَيْرُ، بْنُ يَسَارٍ الأَنْصَارِيُّ عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ الأَنْصَارِيِّ، أَنَّهُ أَخْبَرَهُ أَنَّ نَفَرًا مِنْهُمُ انْطَلَقُوا إِلَى خَيْبَرَ فَتَفَرَّقُوا فِيهَا فَوَجَدُوا أَحَدَهُمْ قَتِيلاً ‏.‏ وَسَاقَ الْحَدِيثَ وَقَالَ فِيهِ فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُبْطِلَ دَمَهُ فَوَدَاهُ مِائَةً مِنْ إِبِلِ الصَّدَقَةِ ‏.‏\hadithno{4348}\hadithtrans{Bushair b. Yasar al-Ansari reported on the authority of Sahl b. Abu Hathma al-Ansari that some men (of his tribe went to Khaibar, and they were separated from one another, and they found one of them slain. The rest of the hadith is the same. And it was said in this connection:Allah's Messenger (may peace be him) did not approve of his blood go waste. He paid blood-wit of one hundred camels of Sadaqa}}
\hadithdefcmd{muslim}{4349}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا بِشْرُ بْنُ عُمَرَ، قَالَ سَمِعْتُ مَالِكَ بْنَ أَنَسٍ، يَقُولُ حَدَّثَنِي أَبُو لَيْلَى بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَهْلٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّهُ أَخْبَرَهُ عَنْ رِجَالٍ، مِنْ كُبَرَاءِ قَوْمِهِ أَنَّ عَبْدَ، اللَّهِ بْنَ سَهْلٍ وَمُحَيِّصَةَ خَرَجَا إِلَى خَيْبَرَ مِنْ جَهْدٍ أَصَابَهُمْ فَأَتَى مُحَيِّصَةُ فَأَخْبَرَ أَنَّ عَبْدَ اللَّهِ بْنَ سَهْلٍ قَدْ قُتِلَ وَطُرِحَ فِي عَيْنٍ أَوْ فَقِيرٍ فَأَتَى يَهُودَ فَقَالَ أَنْتُمْ وَاللَّهِ قَتَلْتُمُوهُ ‏.‏ قَالُوا وَاللَّهِ مَا قَتَلْنَاهُ ‏.‏ ثُمَّ أَقْبَلَ حَتَّى قَدِمَ عَلَى قَوْمِهِ فَذَكَرَ لَهُمْ ذَلِكَ ثُمَّ أَقْبَلَ هُوَ وَأَخُوهُ حُوَيِّصَةُ وَهُوَ أَكْبَرُ مِنْهُ وَعَبْدُ الرَّحْمَنِ بْنُ سَهْلٍ فَذَهَبَ مُحَيِّصَةُ لِيَتَكَلَّمَ وَهُوَ الَّذِي كَانَ بِخَيْبَرَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمُحَيِّصَةَ ‏"‏ كَبِّرْ كَبِّرْ ‏"‏ ‏.‏ يُرِيدُ السِّنَّ فَتَكَلَّمَ حُوَيِّصَةُ ثُمَّ تَكَلَّمَ مُحَيِّصَةُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِمَّا أَنْ يَدُوا صَاحِبَكُمْ وَإِمَّا أَنْ يُؤْذِنُوا بِحَرْبٍ ‏"‏ ‏.‏ فَكَتَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَيْهِمْ فِي ذَلِكَ فَكَتَبُوا إِنَّا وَاللَّهِ مَا قَتَلْنَاهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِحُوَيِّصَةَ وَمُحَيِّصَةَ وَعَبْدِ الرَّحْمَنِ ‏"‏ أَتَحْلِفُونَ وَتَسْتَحِقُّونَ دَمَ صَاحِبِكُمْ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَتَحْلِفُ لَكُمْ يَهُودُ ‏"‏ ‏.‏ قَالُوا لَيْسُوا بِمُسْلِمِينَ ‏.‏ فَوَدَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عِنْدِهِ فَبَعَثَ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم مِائَةَ نَاقَةٍ حَتَّى أُدْخِلَتْ عَلَيْهِمُ الدَّارَ ‏.‏ فَقَالَ سَهْلٌ فَلَقَدْ رَكَضَتْنِي مِنْهَا نَاقَةٌ حَمْرَاءُ ‏.‏\hadithno{4349}\hadithtrans{Abu Laila 'Abdullah b. 'Abd al-Rahman b. Sahl reported that the elderly persons of (the tribe) had informed Sahl b. Abu Hathma that 'Abdullah b. Sahl and Muhayyisa went out to Khaibar under some distress which had afflicted them. Muhayyisa came and informed that Abdutlah b. Sahl had been killed, and (his dead body) had been thrown in a well or in a ditch. He came to the Jews and said:By Allah, it is you who have killed him. They said: By Allah, we have not killed him. He then came to his people, and made mention of that to them. Then came he and his brother Huwayyisa, and he was older than he, and 'Abd al-Rahman b. Sahl. Then Muhayyisa went to speak, and it was he who had accompanied ('Abdullah) to Khaibar, whereupon Allah's Messenger (ﷺ) said to Muhayyisa: Observe greatness of the great (he meant the seniority of age). Then Huwayyisa spoke and then Muhayyisa also spoke. Thereupon Allah's Messenger (ﷺ) said: They should either pay blood-wit for your companion, or be prepared for war. Allah's Messenger (ﷺ) wrote about it to them (to the Jews). They wrote: Verily, by Allah, we have not killed him. Thereupon Allah's Messenger (ﷺ) said to Huwayyisa and Muhayyisa and Abd al-Rahman: Are you prepared to take oath in order to entitle yourselves for the blood-wit of your companion? They said: No. He (the Holy Prophet) said: Then the Jews will take oath (of their innocence). They said: They are not Muslims. Allah's Messenger (ﷺ), however, himself paid the blood-wit to them and sent to them one hundred camels until they entered into their houses, Sahl said: One red she-camel among them kicked me}}
\hadithdefcmd{muslim}{4350}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالَ أَبُو الطَّاهِرِ حَدَّثَنَا وَقَالَ، حَرْمَلَةُ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَسُلَيْمَانُ، بْنُ يَسَارٍ مَوْلَى مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم عَنْ رَجُلٍ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الأَنْصَارِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقَرَّ الْقَسَامَةَ عَلَى مَا كَانَتْ عَلَيْهِ فِي الْجَاهِلِيَّةِ ‏.‏\hadithno{4350}\hadithtrans{Sulaiman b. Yasar, the freed slave of Maimuna, the wife of Allah's Apostle (ﷺ), narrated from one of the Ansari Companions of Allah's Messenger (ﷺ) that Allah's Messenger (ﷺ) retained (the practice) of Qasama as it was in the pre-Islamic days}}
\hadithdefcmd{muslim}{4351}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، حَدَّثَنَا ابْنُ، شِهَابٍ بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏ وَزَادَ وَقَضَى بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ نَاسٍ مِنَ الأَنْصَارِ فِي قَتِيلٍ ادَّعَوْهُ عَلَى الْيَهُودِ ‏.‏\hadithno{4351}\hadithtrans{This hadith has been narrated on the authority of Ibn Shihab with the same chain of transmitters but with this addition:" Allah's Messenger (ﷺ) decided (according to Qasama) between the persons of Ansar (and yours) about a slain (Muslim) for which they made claim against the Jews}}
\hadithdefcmd{muslim}{4352}{وَحَدَّثَنَا حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، أَخْبَرَاهُ عَنْ نَاسٍ، مِنَ الأَنْصَارِ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ ابْنِ جُرَيْجٍ ‏.‏\hadithno{4352}\hadithtrans{This hadith has been narrated on the authority of Abu Salama b. 'Abd al-Rahman and Sulaiman b. Yasar}}
\hadithdefcmd{muslim}{4353}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ كِلاَهُمَا عَنْ هُشَيْمٍ، - وَاللَّفْظُ لِيَحْيَى - قَالَ أَخْبَرَنَا هُشَيْمٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، وَحُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ نَاسًا، مِنْ عُرَيْنَةَ قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ فَاجْتَوَوْهَا فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ شِئْتُمْ أَنْ تَخْرُجُوا إِلَى إِبِلِ الصَّدَقَةِ فَتَشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا ‏"‏ ‏.‏ فَفَعَلُوا فَصَحُّوا ثُمَّ مَالُوا عَلَى الرِّعَاءِ فَقَتَلُوهُمْ وَارْتَدُّوا عَنِ الإِسْلاَمِ وَسَاقُوا ذَوْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَبَعَثَ فِي أَثْرِهِمْ فَأُتِيَ بِهِمْ فَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ وَتَرَكَهُمْ فِي الْحَرَّةِ حَتَّى مَاتُوا\hadithno{4353}\hadithtrans{Anas b. Malik reported that some people belonging (to the tribe) of 'Uraina came to Allah's Messenger (ﷺ) at Medina, but they found its climate uncogenial. So Allah's Messenger (ﷺ) said to them:If you so like, you may go to the camels of Sadaqa and drink their milk and urine. They did so and were all right. They then fell upon the shepherds and killed them and turned apostates from Islam and drove off the camels of the Prophet (ﷺ). This news reached Allah's Apostle (ﷺ) and he sent (people) on their track and they were (brought) and handed over to him. He (the Holy Prophet) got their hands cut off, and their feet, and put out their eyes, and threw them on the stony ground until they died}}
\hadithdefcmd{muslim}{4354}{حَدَّثَنَا أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ الصَّبَّاحِ وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ حَجَّاجِ بْنِ أَبِي عُثْمَانَ، حَدَّثَنِي أَبُو رَجَاءٍ، مَوْلَى أَبِي قِلاَبَةَ عَنْ أَبِي قِلاَبَةَ، حَدَّثَنِي أَنَسٌ، أَنَّ نَفَرًا، مِنْ عُكْلٍ ثَمَانِيَةً قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَايَعُوهُ عَلَى الإِسْلاَمِ فَاسْتَوْخَمُوا الأَرْضَ وَسَقُمَتْ أَجْسَامُهُمْ فَشَكَوْا ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ ‏ "‏ أَلاَ تَخْرُجُونَ مَعَ رَاعِينَا فِي إِبِلِهِ فَتُصِيبُونَ مِنْ أَبْوَالِهَا وَأَلْبَانِهَا ‏"‏ ‏.‏ فَقَالُوا بَلَى ‏.‏ فَخَرَجُوا فَشَرِبُوا مِنْ أَبْوَالِهَا وَأَلْبَانِهَا فَصَحُّوا فَقَتَلُوا الرَّاعِيَ وَطَرَدُوا الإِبِلَ فَبَلغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَبَعَثَ فِي آثَارِهِمْ فَأُدْرِكُوا فَجِيءَ بِهِمْ فَأَمَرَ بِهِمْ فَقُطِعَتْ أَيْدِيهِمْ وَأَرْجُلُهُمْ وَسُمِرَ أَعْيُنُهُمْ ثُمَّ نُبِذُوا فِي الشَّمْسِ حَتَّى مَاتُوا ‏.‏ وَقَالَ ابْنُ الصَّبَّاحِ فِي رِوَايَتِهِ وَاطَّرَدُوا النَّعَمَ ‏.‏ وَقَالَ وَسُمِّرَتْ أَعْيُنُهُمْ ‏.‏\hadithno{4354}\hadithtrans{Anas reported:Eight men of the tribe of 'Ukl came to Allah's Messenger (ﷺ) and swore allegiance to him on Islam, but found the climate of that land uncogenial to their health and thus they became sick, and they made complaint of that to Allah's Messenger (ﷺ), and he said: Why don't you go to (the fold) of our camels along with our shepherd, and make use of their milk and urine. They said: Yes. They set out and drank their (camels') milk and urine and regained their health. They killed the shepherd and drove away the camels. This (news) reached Allah's Messenger (ﷺ) and he sent them on their track and they were caught and brought to him (the Holy Prophet). He commanded about them, and (thus) their hands and feet were cut off and their eyes were gouged and then they were thrown in the sun, until they died. This hadith has been narrated on the authority of Ibn al-Sabbah with a slight variation of words}}
\hadithdefcmd{muslim}{4355}{وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي رَجَاءٍ، مَوْلَى أَبِي قِلاَبَةَ قَالَ قَالَ أَبُو قِلاَبَةَ حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ قَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَوْمٌ مِنْ عُكْلٍ أَوْ عُرَيْنَةَ فَاجْتَوَوُا الْمَدِينَةَ فَأَمَرَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِلِقَاحٍ وَأَمَرَهُمْ أَنْ يَشْرَبُوا مِنْ أَبْوَالِهَا وَأَلْبَانِهَا ‏.‏ بِمَعْنَى حَدِيثِ حَجَّاجِ بْنِ أَبِي عُثْمَانَ ‏.‏ قَالَ وَسُمِرَتْ أَعْيُنُهُمْ وَأُلْقُوا فِي الْحَرَّةِ يَسْتَسْقُونَ فَلاَ يُسْقَوْنَ\hadithno{4355}\hadithtrans{Anas b. Malik reported that some people of the tribe of 'Ukl or 'Uraina came to Allah's Messenger (ﷺ), and they found the climate of Medina uncogenial. Allah's Messenger (ﷺ) commanded them to the milch she-camels and commanded them to drink their urine and their milk. The rest of the hadith is the same (and the concluding words are):" Their eyes were pierced, and they were thrown on the stony ground. They were asking for water, but they were not given water}}
\hadithdefcmd{muslim}{4356}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، حَدَّثَنَا أَزْهَرُ السَّمَّانُ، قَالاَ حَدَّثَنَا ابْنُ عَوْنٍ، حَدَّثَنَا أَبُو رَجَاءٍ، مَوْلَى أَبِي قِلاَبَةَ عَنْ أَبِي قِلاَبَةَ، قَالَ كُنْتُ جَالِسًا خَلْفَ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ فَقَالَ لِلنَّاسِ مَا تَقُولُونَ فِي الْقَسَامَةِ فَقَالَ عَنْبَسَةُ قَدْ حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ كَذَا وَكَذَا فَقُلْتُ إِيَّاىَ حَدَّثَ أَنَسٌ قَدِمَ عَلَى النَّبِيِّ صلى الله عليه وسلم قَوْمٌ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ أَيُّوبَ وَحَجَّاجٍ ‏.‏ قَالَ أَبُو قِلاَبَةَ فَلَمَّا فَرَغْتُ قَالَ عَنْبَسَةُ سُبْحَانَ اللَّهِ - قَالَ أَبُو قِلاَبَةَ - فَقُلْتُ أَتَتَّهِمُنِي يَا عَنْبَسَةُ قَالَ لاَ هَكَذَا حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ لَنْ تَزَالُوا بِخَيْرٍ يَا أَهْلَ الشَّامِ مَادَامَ فِيكُمْ هَذَا أَوْ مِثْلُ هَذَا\hadithno{4356}\hadithtrans{Abu Qilaba reported:I was sitting behind 'Umar b. 'Abd al-'Aziz and he said to the people: What do you say about al-Qasama? Thereupon 'Anbasa said: Anas b Malik narrated to us such and such (hadith pertaining to al-Qasama). I said: This is what Anas had narrated to me: People came to Allah's Apostle (ﷺ), and the rest of the hadith is the same. When I (Abu Qilaba) finished (the narration of this hadith), 'Anbasa said: Hallowed be Allah. I said: Do you blame me (for telling a lie)? He ('Anbasa) said: No. This is how Anas b Malik narrated to us. O people of Syria, you would not be deprived of good, so long as such (a person) or one like him lives amongst you}}
\hadithdefcmd{muslim}{4357}{وَحَدَّثَنَا الْحَسَنُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنَا مِسْكِينٌ، - وَهُوَ ابْنُ بُكَيْرٍ الْحَرَّانِيُّ - أَخْبَرَنَا الأَوْزَاعِيُّ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ثَمَانِيَةُ نَفَرٍ مِنْ عُكْلٍ ‏.‏ بِنَحْوِ حَدِيثِهِمْ ‏.‏ وَزَادَ فِي الْحَدِيثِ وَلَمْ يَحْسِمْهُمْ ‏.‏\hadithno{4357}\hadithtrans{Anas b. Malik reported:There came to Allah's Messenger (ﷺ) eight persons from the tribe of 'Ukl, but with this addition that he did not cauterise (the wounds which hid been inflicted upon them while punishing them)}}
\hadithdefcmd{muslim}{4358}{وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سِمَاكُ، بْنُ حَرْبٍ عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ أَنَسٍ، قَالَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم نَفَرٌ مِنْ عُرَيْنَةَ فَأَسْلَمُوا وَبَايَعُوهُ وَقَدْ وَقَعَ بِالْمَدِينَةِ الْمُومُ - وَهُوَ الْبِرْسَامُ - ثُمَّ ذَكَرَ نَحْوَ حَدِيثِهِمْ وَزَادَ وَعِنْدَهُ شَبَابٌ مِنَ الأَنْصَارِ قَرِيبٌ مِنْ عِشْرِينَ فَأَرْسَلَهُمْ إِلَيْهِمْ وَبَعَثَ مَعَهُمْ قَائِفًا يَقْتَصُّ أَثَرَهُمْ ‏.‏\hadithno{4358}\hadithtrans{Anas reported:There came to Allah's Messenger (ﷺ) some ponple from 'Uraina. They embraced Islam and swore allegiance to him and there had spread at that time pleurisy. The rest of the hadith is the same (but with this addition):" There were by his (the Prophet's) side about twenty young men of the Ansar; he sent them (behind) them (culprits), and he also sent along with them one expert in following the track so that he might trace their footprints}}
\hadithdefcmd{muslim}{4359}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، ح. وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، وَفِي حَدِيثِ هَمَّامٍ قَدِمَ عَلَى النَّبِيِّ صلى الله عليه وسلم رَهْطٌ مِنْ عُرَيْنَةَ وَفِي حَدِيثِ سَعِيدٍ مِنْ عُكْلٍ وَعُرَيْنَةَ ‏.‏ بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{4359}\hadithtrans{This hadith has been narrated on the authority of Anas b. Malik through another chain of transmitters}}
\hadithdefcmd{muslim}{4360}{وَحَدَّثَنِي الْفَضْلُ بْنُ سَهْلٍ الأَعْرَجُ، حَدَّثَنَا يَحْيَى بْنُ غَيْلاَنَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَنَسٍ، قَالَ إِنَّمَا سَمَلَ النَّبِيُّ صلى الله عليه وسلم أَعْيُنَ أُولَئِكَ لأَنَّهُمْ سَمَلُوا أَعْيُنَ الرِّعَاءِ ‏.‏\hadithno{4360}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) pierced their eyes because they had pierced the eyes of the shepherds}}
\hadithdefcmd{muslim}{4361}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ يَهُودِيًّا، قَتَلَ جَارِيَةً عَلَى أَوْضَاحٍ لَهَا فَقَتَلَهَا بِحَجَرٍ - قَالَ - فَجِيءَ بِهَا إِلَى النَّبِيِّ صلى الله عليه وسلم وَبِهَا رَمَقٌ فَقَالَ لَهَا ‏ "‏ أَقَتَلَكِ فُلاَنٌ ‏"‏ ‏.‏ فَأَشَارَتْ بِرَأْسِهَا أَنْ لاَ ثُمَّ قَالَ لَهَا الثَّانِيَةَ فَأَشَارَتْ بِرَأْسِهَا أَنْ لاَ ثُمَّ سَأَلَهَا الثَّالِثَةَ فَقَالَتْ نَعَمْ ‏.‏ وَأَشَارَتْ بِرَأْسِهَا فَقَتَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ حَجَرَيْنِ ‏.‏\hadithno{4361}\hadithtrans{Anas b. Malik reported that a Jew killed a girl with a stone for her silver ornaments. She was brought to Allah's Messenger (ﷺ) when there was yet some life in her. He (the Holy Prophet) said to her:Has so and so killed you? She indicated with the nod of her head: No. He said for the second time, and she again said: No with the nod of her head. He asked for the third time, and she said: Yes with the nod of her head and Allah's Messenger (ﷺ) commanded to crush his head between two stones}}
\hadithdefcmd{muslim}{4362}{وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ يَعْنِي ابْنَ الْحَارِثِ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ إِدْرِيسَ، كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ وَفِي حَدِيثِ ابْنِ إِدْرِيسَ فَرَضَخَ رَأْسَهُ بَيْنَ حَجَرَيْنِ ‏.‏\hadithno{4362}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters and in the hadith narrated on the authority of Ibn Idris (the words are):" He (commanded) to crush his head between two stones}}
\hadithdefcmd{muslim}{4363}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، مِنَ الْيَهُودِ قَتَلَ جَارِيَةً مِنَ الأَنْصَارِ عَلَى حُلِيٍّ لَهَا ثُمَّ أَلْقَاهَا فِي الْقَلِيبِ وَرَضَخَ رَأْسَهَا بِالْحِجَارَةِ فَأُخِذَ فَأُتِيَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِهِ أَنْ يُرْجَمَ حَتَّى يَمُوتَ فَرُجِمَ حَتَّى مَاتَ ‏.‏\hadithno{4363}\hadithtrans{Anas reported that a Jew killed a girl of the Ansar for her ornaments and then threw her in a well and smashed her head with a stone. He was caught and brought to the Messenger of Allah (ﷺ), and he commanded that he should be stoned to death. So he was stoned until he died}}
\hadithdefcmd{muslim}{4364}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي مَعْمَرٌ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4364}\hadithtrans{This hadith has been narrated on the authority of Ayyub with the same chain of transmitters}}
\hadithdefcmd{muslim}{4365}{وَحَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ جَارِيَةً، وُجِدَ رَأْسُهَا قَدْ رُضَّ بَيْنَ حَجَرَيْنِ فَسَأَلُوهَا مَنْ صَنَعَ هَذَا بِكِ فُلاَنٌ فُلاَنٌ حَتَّى ذَكَرُوا يَهُودِيًّا فَأَوْمَتْ بِرَأْسِهَا فَأُخِذَ الْيَهُودِيُّ فَأَقَرَّ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُرَضَّ رَأْسُهُ بِالْحِجَارَةِ ‏.‏\hadithno{4365}\hadithtrans{Anas b. Malik reported:A girl was found with her head crushed between two stones. They asked her as to who had done that-has so and so (done it) until they mentioned a Jew. She indicated with the nod of her head (that it was so). So the Jew was caught, and he made confession (of his guilt). And Allah's Messenger (ﷺ) commanded that his head be smashed with stones}}
\hadithdefcmd{muslim}{4366}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَاتَلَ يَعْلَى ابْنُ مُنْيَةَ أَوِ ابْنُ أُمَيَّةَ رَجُلاً فَعَضَّ أَحَدُهُمَا صَاحِبَهُ فَانْتَزَعَ يَدَهُ مِنْ فَمِهِ فَنَزَعَ ثَنِيَّتَهُ - وَقَالَ ابْنُ الْمُثَنَّى ثَنِيَّتَيْهِ - فَاخْتَصَمَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَيَعَضُّ أَحَدُكُمْ كَمَا يَعَضُّ الْفَحْلُ لاَ دِيَةَ لَهُ ‏"‏ ‏.‏\hadithno{4366}\hadithtrans{Imran b. Husain reported:Ya'la b. Munya or Ibn Umayya fought with a person, and the one bit the hand of the other. And he tried to draw his hand from his mouth and thus his foreteeth ware pulled out. They referred their dispute to Allah's Apostle (ﷺ), whereupon he said: Does any one of you bite as the camel bites? So there is no blood-wit for it}}
\hadithdefcmd{muslim}{4367}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عَطَاءٍ، عَنِ ابْنِ يَعْلَى، عَنْ يَعْلَى، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4367}\hadithtrans{This hadith has been transmitted on the authority of Ya'la}}
\hadithdefcmd{muslim}{4368}{حَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذٌ، - يَعْنِي ابْنَ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، عَضَّ ذِرَاعَ رَجُلٍ فَجَذَبَهُ فَسَقَطَتْ ثَنِيَّتُهُ فَرُفِعَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَبْطَلَهُ وَقَالَ ‏ "‏ أَرَدْتَ أَنْ تَأْكُلَ لَحْمَهُ ‏"‏ ‏.‏\hadithno{4368}\hadithtrans{Imran b. Husain reported that a person bit the arm of another person; he pulled it out and his foretooth fell down. This matter was taken to Allah's Apostle (ﷺ), and he turned it down saying:Did you want to eat his flesh?}}
\hadithdefcmd{muslim}{4369}{حَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ بُدَيْلٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، أَنَّ أَجِيرًا، لِيَعْلَى ابْنِ مُنْيَةَ عَضَّ رَجُلٌ ذِرَاعَهُ فَجَذَبَهَا فَسَقَطَتْ ثَنِيَّتُهُ فَرُفِعَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَبْطَلَهَا وَقَالَ ‏ " أَرَدْتَ أَنْ تَقْضَمَهَا كَمَا يَقْضَمُ الْفَحْلُ ‏"‏ ‏.‏\hadithno{4369}\hadithtrans{Safwan b. Ya'la reported that a person bit the arm of the servant of Ya'la b. Munya. He pulled it and his foretooth fell. The matter was referred to Allah's Apostle (ﷺ) and he turned it down and said:Did you intend to bite his hand, as the camel bites?}}
\hadithdefcmd{muslim}{4370}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، حَدَّثَنَا قُرَيْشُ بْنُ أَنَسٍ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدِ، بْنِ سِيرِينَ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، عَضَّ يَدَ رَجُلٍ فَانْتَزَعَ يَدَهُ فَسَقَطَتْ ثَنِيَّتُهُ أَوْ ثَنَايَاهُ فَاسْتَعْدَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَأْمُرُنِي تَأْمُرُنِي أَنْ آمُرَهُ أَنْ يَدَعَ يَدَهُ فِي فِيكَ تَقْضَمُهَا كَمَا يَقْضَمُ الْفَحْلُ ادْفَعْ يَدَكَ حَتَّى يَعَضَّهَا ثُمَّ انْتَزِعْهَا ‏"‏ ‏.‏\hadithno{4370}\hadithtrans{Imran b. Husain reported that a person bit the hand of a person. He withdrew his hand and his foretooth or foreteeth fell down. He (the man who lost his teeth) referred the matter to Allah's Messenger (ﷺ) and he said, What do you want me to do? Do you ask me that I should order him to put his hand in your mouth, and you should bite it as the camel bites? (If you want retaliation, then the only way out is) that you put your hand in his mouth (allow him) to bite that and then draw it away}}
\hadithdefcmd{muslim}{4371}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا عَطَاءٌ، عَنْ صَفْوَانَ بْنِ يَعْلَى ابْنِ، مُنْيَةَ عَنْ أَبِيهِ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ وَقَدْ عَضَّ يَدَ رَجُلٍ فَانْتَزَعَ يَدَهُ فَسَقَطَتْ ثَنِيَّتَاهُ - يَعْنِي الَّذِي عَضَّهُ - قَالَ فَأَبْطَلَهَا النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏ "‏ أَرَدْتَ أَنْ تَقْضَمَهُ كَمَا يَقْضَمُ الْفَحْلُ ‏"‏ ‏.‏\hadithno{4371}\hadithtrans{Safwan b. Ya'la b. Munya reported on the authority of his father that there came to Allah's Apostle (ﷺ) a person who had bitten the hand of another person and who had withdrawn his hand (and as a result thereof) his foreteeth had fallen (those which had bitten). The Apostle of Allah (ﷺ) turned down his (claim), and said:Do you wish to bite as the camel bites?}}
\hadithdefcmd{muslim}{4372}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، أَخْبَرَنِي صَفْوَانُ بْنُ يَعْلَى بْنِ أُمَيَّةَ، عَنْ أَبِيهِ، قَالَ غَزَوْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم غَزْوَةَ تَبُوكَ - قَالَ وَكَانَ يَعْلَى يَقُولُ تِلْكَ الْغَزْوَةُ أَوْثَقُ عَمَلِي عِنْدِي - فَقَالَ عَطَاءٌ قَالَ صَفْوَانُ قَالَ يَعْلَى كَانَ لِي أَجِيرٌ فَقَاتَلَ إِنْسَانًا فَعَضَّ أَحَدُهُمَا يَدَ الآخَرِ - قَالَ لَقَدْ أَخْبَرَنِي صَفْوَانُ أَيُّهُمَا عَضَّ الآخَرَ - فَانْتَزَعَ الْمَعْضُوضُ يَدَهُ مِنْ فِي الْعَاضِّ فَانْتَزَعَ إِحْدَى ثَنِيَّتَيْهِ فَأَتَيَا النَّبِيَّ صلى الله عليه وسلم فَأَهْدَرَ ثَنِيَّتَهُ ‏.‏\hadithno{4372}\hadithtrans{Safwan b. Ya'la b. Umayya thus reported from his father:I participated in the expedition to Tabuk with Allah's Apostle (ﷺ). And Ya'la used to say: That was the most weighty of my deeds, in my opinion. Safwan said that Ya'la had stated: I had a servant; he quarrelled with another person, and the one bit the hand of the other. ('Ata' said that Safwan had told him which one had bitten the hand of the other.) So he whose hand was bitten drew ill from (the mouth) of the one who had bitten it and (in this scuffle) one of his foreteeth was also drawn out. They both came to Allah's Apostle (ﷺ) and he declared his (claim for the compensation of) tooth as invalid}}
\hadithdefcmd{muslim}{4373}{وَحَدَّثَنَاهُ عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4373}\hadithtrans{This hadith has been narrated on the authority of Juraij with the same chain of transmitters}}
\hadithdefcmd{muslim}{4374}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ أُخْتَ الرُّبَيِّعِ أُمَّ حَارِثَةَ، جَرَحَتْ إِنْسَانًا فَاخْتَصَمُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْقِصَاصَ الْقِصَاصَ ‏"‏ ‏.‏ فَقَالَتْ أُمُّ الرَّبِيعِ يَا رَسُولَ اللَّهِ أَيُقْتَصُّ مِنْ فُلاَنَةَ وَاللَّهِ لاَ يُقْتَصُّ مِنْهَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ سُبْحَانَ اللَّهِ يَا أُمَّ الرَّبِيعِ الْقِصَاصُ كِتَابُ اللَّهِ ‏"‏ ‏.‏ قَالَتْ لاَ وَاللَّهِ لاَ يُقْتَصُّ مِنْهَا أَبَدًا ‏.‏ قَالَ فَمَا زَالَتْ حَتَّى قَبِلُوا الدِّيَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ عِبَادِ اللَّهِ مَنْ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏ ‏.‏\hadithno{4374}\hadithtrans{Anas reported that Umm Haritha, the sister of Rubayyi' (she was the father's sister of Hadrat Anas) injured a person (she broke his teeth). The dispute was referred to Allah's Apostle (ﷺ). Allah's Messenger (ﷺ) said:Retribution, retribution. Umm Rubayyi' said: Messenger of Allah, will retribution be taken from so and so? By Allah, it shall not be taken from her (i. e. from Umm Haritha). Thereupon Allah's Apostle said: Hallowed be Allah. O Umm Rubayyi', Qisas (retribution is a command, prescribed) in the Book of Allah. She said: No, by Allah, Qisas will never be taken from her; and she went on saying this until they (the relatives of the one who had been injured) accepted the blood-wit. Thereupon Allah's Messenger (ﷺ) said: Verily there are amongst the servants of Allah (such pious persons) who, if they take oath of Allah, He honours it}}
\hadithdefcmd{muslim}{4375}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، وَأَبُو مُعَاوِيَةَ وَوَكِيعٌ عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ إِلاَّ بِإِحْدَى ثَلاَثٍ الثَّيِّبُ الزَّانِ وَالنَّفْسُ بِالنَّفْسِ وَالتَّارِكُ لِدِينِهِ الْمُفَارِقُ لِلْجَمَاعَةِ ‏"‏ ‏.‏\hadithno{4375}\hadithtrans{Abdullah (b. Mas'ud) reported Allah's Messenger (ﷺ) as saying:It is not permissible to take the life of a Muslim who bears testimony (to the fact that there is no god but Allah, and I am the Messenger of Allah, but in one of the three cases: the married adulterer, a life for life, and the deserter of his Din (Islam), abandoning the community}}
\hadithdefcmd{muslim}{4376}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4376}\hadithtrans{This hadith has been narrated on the authority of A'mash}}
\hadithdefcmd{muslim}{4377}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لأَحْمَدَ - قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، بْنُ مَهْدِيٍّ عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَامَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ وَالَّذِي لاَ إِلَهَ غَيْرُهُ لاَ يَحِلُّ دَمُ رَجُلٍ مُسْلِمٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ إِلاَّ ثَلاَثَةُ نَفَرٍ التَّارِكُ الإِسْلاَمَ الْمُفَارِقُ لِلْجَمَاعَةِ أَوِ الْجَمَاعَةَ - شَكَّ فِيهِ أَحْمَدُ - وَالثَّيِّبُ الزَّانِي وَالنَّفْسُ بِالنَّفْسِ ‏"‏ ‏.‏ قَالَ الأَعْمَشُ فَحَدَّثْتُ بِهِ، إِبْرَاهِيمَ فَحَدَّثَنِي عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، بِمِثْلِهِ ‏.‏\hadithno{4377}\hadithtrans{Abdullah (b. Mas'ud) reported:Allah's Messenger (ﷺ) stood up and said: By Him besides Whom there is no god but He, the blood of a Muslim who bears the testimony that there is no god but Allah, and I am His Messenger, may be lawfully shed only in case of three persons: the one who abandons Islam, and deserts the community [Ahmad, one of the narrators, is doubtful whether the Prophet (ﷺ) used the word li'l-jama'ah or al-jama'ah), and the married adulterer, and life for life}}
\hadithdefcmd{muslim}{4378}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، وَالْقَاسِمُ بْنُ زَكَرِيَّاءَ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنِ الأَعْمَشِ، بِالإِسْنَادَيْنِ جَمِيعًا ‏.‏ نَحْوَ حَدِيثِ سُفْيَانَ وَلَمْ يَذْكُرَا فِي الْحَدِيثِ قَوْلَهُ ‏ "‏ وَالَّذِي لاَ إِلَهَ غَيْرُهُ ‏"‏ ‏.‏\hadithno{4378}\hadithtrans{This hadith has been reported on the authority of A'mash with the same chain of narrators but with a slight variation of words, i. e. he did not say:By Him besides Whom there is no god}}
\hadithdefcmd{muslim}{4379}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ، اللَّهِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُقْتَلُ نَفْسٌ ظُلْمًا إِلاَّ كَانَ عَلَى ابْنِ آدَمَ الأَوَّلِ كِفْلٌ مِنْ دَمِهَا لأَنَّهُ كَانَ أَوَّلَ مَنْ سَنَّ الْقَتْلَ ‏"‏ ‏.‏\hadithno{4379}\hadithtrans{Abdullah (b. Mas'ud) reported:Allah's Apostle (ﷺ) having said: No person who is killed unjustly, but the share of (this offence of his also) falls upon the first son of Adam, for he was the first to introduce killing}}
\hadithdefcmd{muslim}{4380}{وَحَدَّثَنَاهُ عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، وَعِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ جَرِيرٍ وَعِيسَى بْنِ يُونُسَ ‏ "‏ لأَنَّهُ سَنَّ الْقَتْلَ ‏"‏ ‏.‏ لَمْ يَذْكُرَا أَوَّلَ ‏.‏\hadithno{4380}\hadithtrans{This hadith has been narrated on the authority of Jarir and 'Isa b. Yunus with a slight variation of words}}
\hadithdefcmd{muslim}{4381}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، جَمِيعًا عَنْ وَكِيعٍ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَوَكِيعٌ عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَّلُ مَا يُقْضَى بَيْنَ النَّاسِ يَوْمَ الْقِيَامَةِ فِي الدِّمَاءِ ‏"‏ ‏.‏\hadithno{4381}\hadithtrans{Abdullah b. (Mas'ud) reported Allah's Messenger (ﷺ) as saying:The first (thing) that will be decided among people on the Day of Judgment will pertain to bloodshed}}
\hadithdefcmd{muslim}{4382}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - ح وَحَدَّثَنِي بِشْرُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا ابْنُ، الْمُثَنَّى وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، كُلُّهُمْ عَنْ شُعْبَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّ بَعْضَهُمْ قَالَ عَنْ شُعْبَةَ ‏"‏ يُقْضَى ‏"‏ ‏.‏ وَبَعْضُهُمْ قَالَ ‏"‏ يُحْكَمُ بَيْنَ النَّاسِ ‏"‏ ‏.‏\hadithno{4382}\hadithtrans{This hadith has been narrated on the authority of 'Abdullah through another chain of transmitters with a slight variation of words}}
\hadithdefcmd{muslim}{4383}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَيَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، - وَتَقَارَبَا فِي اللَّفْظِ - قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنِ ابْنِ أَبِي بَكْرَةَ، عَنْ أَبِي، بَكْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِنَّ الزَّمَانَ قَدِ اسْتَدَارَ كَهَيْئَتِهِ يَوْمَ خَلَقَ اللَّهُ السَّمَوَاتِ وَالأَرْضَ السَّنَةُ اثْنَا عَشَرَ شَهْرًا مِنْهَا أَرْبَعَةٌ حُرُمٌ ثَلاَثَةٌ مُتَوَالِيَاتٌ ذُو الْقَعْدَةِ وَذُو الْحِجَّةِ وَالْمُحَرَّمُ وَرَجَبٌ شَهْرُ مُضَرَ الَّذِي بَيْنَ جُمَادَى وَشَعْبَانَ - ثُمَّ قَالَ - أَىُّ شَهْرٍ هَذَا ‏"‏ ‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ - قَالَ - فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ ‏.‏ قَالَ ‏"‏ أَلَيْسَ ذَا الْحِجَّةِ ‏"‏ ‏.‏ قُلْنَا بَلَى ‏.‏ قَالَ ‏"‏ فَأَىُّ بَلَدٍ هَذَا ‏"‏ ‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ - قَالَ - فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ ‏.‏ قَالَ ‏"‏ أَلَيْسَ الْبَلْدَةَ ‏"‏ ‏.‏ قُلْنَا بَلَى ‏.‏ قَالَ ‏"‏ فَأَىُّ يَوْمٍ هَذَا ‏"‏ ‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ - قَالَ - فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ ‏.‏ قَالَ ‏"‏ أَلَيْسَ يَوْمَ النَّحْرِ ‏"‏ ‏.‏ قُلْنَا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ - قَالَ مُحَمَّدٌ وَأَحْسِبُهُ قَالَ - وَأَعْرَاضَكُمْ حَرَامٌ عَلَيْكُمْ كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا وَسَتَلْقَوْنَ رَبَّكُمْ فَيَسْأَلُكُمْ عَنْ أَعْمَالِكُمْ فَلاَ تَرْجِعُنَّ بَعْدِي كُفَّارًا - أَوْ ضُلاَّلاً - يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ أَلاَ لِيُبَلِّغِ الشَّاهِدُ الْغَائِبَ فَلَعَلَّ بَعْضَ مَنْ يُبَلَّغُهُ يَكُونُ أَوْعَى لَهُ مِنْ بَعْضِ مَنْ سَمِعَهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلاَ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ قَالَ ابْنُ حَبِيبٍ فِي رِوَايَتِهِ ‏"‏ وَرَجَبُ مُضَرَ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ ‏"‏ فَلاَ تَرْجِعُوا بَعْدِي ‏"‏ ‏.‏\hadithno{4383}\hadithtrans{Abu Bakra reported that (in the Farewell Address) Allah's Apostle (ﷺ) said:Time has completed a cycle and come to the state of the day when Allah created the heavens and the earth. The year is constituted of twelve months, of which four are sacred; three of them consecutive, viz. Dhu'l-Qa'da, Dhu'l- Hijja and Muharram, and also Rajab the month of Mudar which comes between Jumada and Sha'ban. He (the Holy Prophet) then said: which month is this? We said Allah and His Messenger know best. He (the narrator) said: He (the Holy Prophet) remained silent for some time until we thought that he would give it a name other than that (by which it was known). He said: Is it not Dha'l-Hijja? We said: Yes. He (the Holy Prophet) said: Which city is this? We said: Allah and His Messenger know best. He (the Holy Prophety remained silent until we thought that he would give it another name. He (the Holy Prophet) said: Is it not the Balda (the city of Mecca)? We said: Yes. He said: What day is this? We said: Allah and His Messenger know best. He (the Holy Prophet) remained silent until we thought that he would give it another name. He said: Is it not the Day of Sacrifice? We said: Allah's Messenger. yes. Thereupon he said: Your blood, your property (Muhammad, one of the narrators, said: I think, he also said this) and your honour are sacred to you like the sacredness of this day of yours, in this city of yours, and in this month of yours. You will soon meet your Lord and He will ask you about your deeds. So do not turn after me unbelievers (or misguided), some of you striking the necks of the others. Behold I let him who is present convey to him who is absent, for many a one whom a message is conveyed has a more retentive memory than one who hears. He again said: Behold! have I not delivered (the message) to you? This hadith has been narrated through another chain of transmitters, but with a slight variation of words}}
\hadithdefcmd{muslim}{4384}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ لَمَّا كَانَ ذَلِكَ الْيَوْمُ قَعَدَ عَلَى بَعِيرِهِ وَأَخَذَ إِنْسَانٌ بِخِطَامِهِ فَقَالَ ‏"‏ أَتَدْرُونَ أَىَّ يَوْمٍ هَذَا ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ سِوَى اسْمِهِ ‏.‏ فَقَالَ ‏"‏ أَلَيْسَ بِيَوْمِ النَّحْرِ ‏"‏ ‏.‏ قُلْنَا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَأَىُّ شَهْرٍ هَذَا ‏"‏ ‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ أَلَيْسَ بِذِي الْحِجَّةِ ‏"‏ ‏.‏ قُلْنَا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَأَىُّ بَلَدٍ هَذَا ‏"‏ ‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ - قَالَ - حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ سِوَى اسْمِهِ ‏.‏ قَالَ ‏"‏ أَلَيْسَ بِالْبَلْدَةِ ‏"‏ ‏.‏ قُلْنَا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ وَأَعْرَاضَكُمْ عَلَيْكُمْ حَرَامٌ كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا فَلْيُبَلِّغِ الشَّاهِدُ الْغَائِبَ ‏"‏ ‏.‏ قَالَ ثُمَّ انْكَفَأَ إِلَى كَبْشَيْنِ أَمْلَحَيْنِ فَذَبَحَهُمَا وَإِلَى جُزَيْعَةٍ مِنَ الْغَنَمِ فَقَسَمَهَا بَيْنَنَا ‏.‏\hadithno{4384}\hadithtrans{Abu Bakra reported that when it was that day (the 10th of Dhu'l-Hijja) he mounted his camel and a person caught its nosestring, whereupon he said:Do you know which day is this? They said: Allah and His Messenger know best. (The Prophet [may peace be upon him] kept silent) until we thought that he would give that another name. He said: Is it not the day of Nahr (Sacrifice) (10th of Dhu'l- Hijja)? We said: Allah's Messenger, yes. He (again) said: Which month is it? We said: Allah and His Messenger knows best. He said: Is it not Dhu'l-Hijja? We said: Allah's Messenger, yes. He said: Which city is this? We said: Allah and His Messenger know best. He (the narrator) said (that the Prophet kept silent until we thought that he would give it another name besides its (original) name. He said: Is it not Balda (the city of Mecca)? We said: Yes, Allah's Messenger. He (then) said: Verily your blood (lives) and your property and your honour are as sacred unto you as sacred is this day of yours, in this month of yours, in this city of yours. Let him who is present convey it to one who is absent. He then turned his attention towards two multicoloured (black and white) rams and slaughtered them, and two goats, and distributed them amongst us}}
\hadithdefcmd{muslim}{4385}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، عَنِ ابْنِ عَوْنٍ، قَالَ قَالَ مُحَمَّدٌ قَالَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرَةَ عَنْ أَبِيهِ قَالَ لَمَّا كَانَ ذَلِكَ الْيَوْمُ جَلَسَ النَّبِيُّ صلى الله عليه وسلم عَلَى بَعِيرٍ - قَالَ - وَرَجُلٌ آخِذٌ بِزِمَامِهِ - أَوْ قَالَ بِخِطَامِهِ - فَذَكَرَ نَحْوَ حَدِيثِ يَزِيدَ بْنِ زُرَيْعٍ ‏.‏\hadithno{4385}\hadithtrans{Abu Bakra reported that when it was the day of (Dhu'l-Hijja) Allah's Apostle (ﷺ) mounted the camel and addressed and a person had been holding its nosestring. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4386}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سِيرِينَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، وَعَنْ رَجُلٍ، آخَرَ هُوَ فِي نَفْسِي أَفْضَلُ مِنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ وَأَحْمَدُ بْنُ خِرَاشٍ قَالاَ حَدَّثَنَا أَبُو عَامِرٍ عَبْدُ الْمَلِكِ بْنُ عَمْرٍو حَدَّثَنَا قُرَّةُ بِإِسْنَادِ يَحْيَى بْنِ سَعِيدٍ - وَسَمَّى الرَّجُلَ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ - عَنْ أَبِي بَكْرَةَ قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ النَّحْرِ فَقَالَ ‏"‏ أَىُّ يَوْمٍ هَذَا ‏"‏ ‏.‏ وَسَاقُوا الْحَدِيثَ بِمِثْلِ حَدِيثِ ابْنِ عَوْنٍ غَيْرَ أَنَّهُ لاَ يَذْكُرُ ‏"‏ وَأَعْرَاضَكُمْ ‏"‏ ‏.‏ وَلاَ يَذْكُرُ ثُمَّ انْكَفَأَ إِلَى كَبْشَيْنِ وَمَا بَعْدَهُ وَقَالَ فِي الْحَدِيثِ ‏"‏ كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا إِلَى يَوْمِ تَلْقَوْنَ رَبَّكُمْ أَلاَ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اشْهَدْ ‏"‏ ‏.‏\hadithno{4386}\hadithtrans{This hadith has been narrated on the authority of Abu Bakra through another chain of transmitters (and the words are):" Allah's Messenger (ﷺ) addressed us on the day of Nahr (Sacrifice) and said: What day is this? And the rest of the hadith is the same except that he did not make mention of" your honour," and also did not make mention of this: He then turned his attention towards two rams and what follows, and in a hadith (the words pertaining to sacred- ness are recorded in this way):" Like the sacredness of this day of yours, in this month of yours, in this city of yours to the day when you will meet your Lord. Behold, have I not conveyed (the Message of God)? They said: Yes. He said: O Allah, bear witness}}
\hadithdefcmd{muslim}{4387}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا أَبُو يُونُسَ، عَنْ سِمَاكِ بْنِ، حَرْبٍ أَنَّ عَلْقَمَةَ بْنَ وَائِلٍ، حَدَّثَهُ أَنَّ أَبَاهُ حَدَّثَهُ قَالَ إِنِّي لَقَاعِدٌ مَعَ النَّبِيِّ صلى الله عليه وسلم إِذْ جَاءَ رَجُلٌ يَقُودُ آخَرَ بِنِسْعَةٍ فَقَالَ يَا رَسُولَ اللَّهِ هَذَا قَتَلَ أَخِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَقَتَلْتَهُ ‏"‏ ‏.‏ فَقَالَ إِنَّهُ لَوْ لَمْ يَعْتَرِفْ أَقَمْتُ عَلَيْهِ الْبَيِّنَةَ ‏.‏ قَالَ نَعَمْ ‏.‏ قَتَلْتُهُ قَالَ ‏"‏ كَيْفَ قَتَلْتَهُ ‏"‏ ‏.‏ قَالَ كُنْتُ أَنَا وَهُوَ نَخْتَبِطُ مِنْ شَجَرَةٍ فَسَبَّنِي فَأَغْضَبَنِي فَضَرَبْتُهُ بِالْفَأْسِ عَلَى قَرْنِهِ فَقَتَلْتُهُ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ مِنْ شَىْءٍ تُؤَدِّيهِ عَنْ نَفْسِكَ ‏"‏ ‏.‏ قَالَ مَا لِي مَالٌ إِلاَّ كِسَائِي وَفَأْسِي ‏.‏ قَالَ ‏"‏ فَتَرَى قَوْمَكَ يَشْتَرُونَكَ ‏"‏ ‏.‏ قَالَ أَنَا أَهْوَنُ عَلَى قَوْمِي مِنْ ذَاكَ ‏.‏ فَرَمَى إِلَيْهِ بِنِسْعَتِهِ ‏.‏ وَقَالَ ‏"‏ دُونَكَ صَاحِبَكَ ‏"‏ ‏.‏ فَانْطَلَقَ بِهِ الرَّجُلُ فَلَمَّا وَلَّى قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ قَتَلَهُ فَهُوَ مِثْلُهُ ‏"‏ ‏.‏ فَرَجَعَ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهُ بَلَغَنِي أَنَّكَ قُلْتَ ‏"‏ إِنْ قَتَلَهُ فَهُوَ مِثْلُهُ ‏"‏ ‏.‏ وَأَخَذْتُهُ بِأَمْرِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا تُرِيدُ أَنْ يَبُوءَ بِإِثْمِكَ وَإِثْمِ صَاحِبِكَ ‏"‏ ‏.‏ قَالَ يَا نَبِيَّ اللَّهِ - لَعَلَّهُ قَالَ - بَلَى ‏.‏ قَالَ ‏"‏ فَإِنَّ ذَاكَ كَذَاكَ ‏"‏ ‏.‏ قَالَ فَرَمَى بِنِسْعَتِهِ وَخَلَّى سَبِيلَهُ ‏.‏\hadithno{4387}\hadithtrans{Alqama b. Wa'il reported on the authority of his-father:While I was sitting in the company of Allah's Apostle (ﷺ), a person came there dragging another one with the help of a strap and said: Allah's Messenger, this man has killed my brother. Allah's Messenger (ﷺ) said to him: Did you kill him? And the other man said: (In case he did not make a confession of this, I shall brine, a witness against him). He (the murderer) said: Yes, I have killed him. He (the Holy Prophet) said: Why did you kill him? He said: I and he won striking down the leaves of a tree and he abused me and enraged me, and to I struck his head with an axe and killed him, whereupon Allah's Messenger (ﷺ) said: Have you anything with you to pay blood-wit on your behalf? He said: I do not possess any property but this robe of mine and this axe of mine. He (the Holy, Prophet) said: Do you think your people will pay ransom for you? He said: I am more insignificant among my people than this (that I would not be able to get this benefit from my tribe). He (the Holy Prophet) threw the strap towards him (the claimant of the blood-wit) saying: Take away your man. The man took him away, and as he returned, Allah's Messenger (ﷺ) said: If he kills him, he will be like him. He returned and said: Allah's Messenger, it has reached me that you have said that" If he killed him, he would be like him." I caught hold of him according to your command, whereupon Allah's Messenger (ﷺ) said: Don't you like that he should take upon him (the burden) of your sin and the sin of your companion (your brother)? He said: Allah's Apostle, why not? The Messenger of Allah (may peace be. upon him) said: If it is so, then let it be. He threw away the strap (around the offender) and set him free}}
\hadithdefcmd{muslim}{4388}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا إِسْمَاعِيلُ، بْنُ سَالِمٍ عَنْ عَلْقَمَةَ بْنِ وَائِلٍ، عَنْ أَبِيهِ، قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَجُلٍ قَتَلَ رَجُلاً فَأَقَادَ وَلِيَّ الْمَقْتُولِ مِنْهُ فَانْطَلَقَ بِهِ وَفِي عُنُقِهِ نِسْعَةٌ يَجُرُّهَا فَلَمَّا أَدْبَرَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏ فَأَتَى رَجُلٌ الرَّجُلَ فَقَالَ لَهُ مَقَالَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَلَّى عَنْهُ ‏.‏ قَالَ إِسْمَاعِيلُ بْنُ سَالِمٍ فَذَكَرْتُ ذَلِكَ لِحَبِيبِ بْنِ أَبِي ثَابِتٍ فَقَالَ حَدَّثَنِي ابْنُ أَشْوَعَ أَنَّ النَّبِيَّ صلى الله عليه وسلم إِنَّمَا سَأَلَهُ أَنْ يَعْفُوَ عَنْهُ فَأَبَى ‏.‏\hadithno{4388}\hadithtrans{Alaqama b. Wa'il reported on the authority of his father that a person was brought to the Messenger of Allah (ﷺ) who had killed another person, and the heir of the person slain had dragged him (to the Holy Prophet) with a strap around his neck. As he turned away Allah's Messenger (ﷺ) said:The killer and the killed are (doomed) to fire. A person came to the other person (the heir of the deceased) and he reported to him the words of the Messenger of Allah (ﷺ), and so he let him off. Isma'il b. Salim said: I made a mention of it to Habib b. Abu Thabit and he said: Ibn Ashwa' reported to me that Allah's Apostle (ﷺ) had asked him to pardon him, but he refused}}
\hadithdefcmd{muslim}{4389}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ امْرَأَتَيْنِ، مِنْ هُذَيْلٍ رَمَتْ إِحْدَاهُمَا الأُخْرَى فَطَرَحَتْ جَنِينَهَا فَقَضَى فِيهِ النَّبِيُّ صلى الله عليه وسلم بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ ‏.‏\hadithno{4389}\hadithtrans{Abu Huraira reported that among two women of the tribe of Hudhail one flung a stone upon the other causing an abortion to her so Allah's Apostle (may peace he upon him) gave judgment that a male or a female slave of best quality be given as compensation}}
\hadithdefcmd{muslim}{4390}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي، هُرَيْرَةَ أَنَّهُ قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي جَنِينِ امْرَأَةٍ مِنْ بَنِي لِحْيَانَ سَقَطَ مَيِّتًا بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ ثُمَّ إِنَّ الْمَرْأَةَ الَّتِي قُضِيَ عَلَيْهَا بِالْغُرَّةِ تُوُفِّيَتْ فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِأَنَّ مِيرَاثَهَا لِبَنِيهَا وَزَوْجِهَا وَأَنَّ الْعَقْلَ عَلَى عَصَبَتِهَا ‏.‏\hadithno{4390}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) gave judgment in case of the abortion of a woman of Banu Lihyan (that the offender and near relative should give compensation in the form of) good quality of a slave or a slave-girl. And the woman about whom the judgment was given for compensation died and thereupon Allah's Messenger (ﷺ) gave judgment that her inheritance goes to her sons and her husband, and the payment of the blood-wit lies with the family of (one who struck her)}}
\hadithdefcmd{muslim}{4391}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، ح وَحَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، قَالَ اقْتَتَلَتِ امْرَأَتَانِ مِنْ هُذَيْلٍ فَرَمَتْ إِحْدَاهُمَا الأُخْرَى بِحَجَرٍ فَقَتَلَتْهَا وَمَا فِي بَطْنِهَا فَاخْتَصَمُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ دِيَةَ جَنِينِهَا غُرَّةٌ عَبْدٌ أَوْ وَلِيدَةٌ وَقَضَى بِدِيَةِ الْمَرْأَةِ عَلَى عَاقِلَتِهَا وَوَرَّثَهَا وَلَدَهَا وَمَنْ مَعَهُمْ فَقَالَ حَمَلُ بْنُ النَّابِغَةِ الْهُذَلِيُّ يَا رَسُولَ اللَّهِ كَيْفَ أَغْرَمُ مَنْ لاَ شَرِبَ وَلاَ أَكَلَ وَلاَ نَطَقَ وَلاَ اسْتَهَلَّ فَمِثْلُ ذَلِكَ يُطَلُّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا هَذَا مِنْ إِخْوَانِ الْكُهَّانِ ‏"‏ ‏.‏ مِنْ أَجْلِ سَجْعِهِ الَّذِي سَجَعَ ‏.‏\hadithno{4391}\hadithtrans{Abu Huraira reported that two women of the tribe of Hudhail fought with each other and one of them flung a stone at the other, killing her and what was in her womb. The case was brought to Allah's Messenger (ﷺ) and he gave judgment that the diyat (indemnity) of her unborn child is a male or a female slave of the best quality, and he also decided that the diyat of the woman is to be paid by her relative on the father's side, and he (the Holy Prophet) made her sons and those who were with them her heirs. Hamal b. al-Nabigha al-Hudhali said:Messenger of Allah, why should I play blood-wit for one who neither drank, nor ate, nor spoke, nor made any noise; it is like a nonentity (it is, therefore, not justifiable to demand blood-wit for it). Thereupon Allah's Messenger (ﷺ) said: He seems to be one of the brothers of soothsavers on account of the rhymed speech which he has composed}}
\hadithdefcmd{muslim}{4392}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ اقْتَتَلَتِ امْرَأَتَانِ ‏.‏ وَسَاقَ الْحَدِيثَ بِقِصَّتِهِ وَلَمْ يَذْكُرْ وَوَرَّثَهَا وَلَدَهَا وَمَنْ مَعَهُمْ ‏.‏ وَقَالَ فَقَالَ قَائِلٌ كَيْفَ نَعْقِلُ وَلَمْ يُسَمِّ حَمَلَ بْنَ مَالِكٍ ‏.‏\hadithno{4392}\hadithtrans{Abu Huraira reported that two women fought-the rest of the hadith is the same but herein no mention has been made of:He made her son and those who were with them her heirs. Someone said: Why should we pay blood-wit? And he did not name Hamal b. Malik}}
\hadithdefcmd{muslim}{4393}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عُبَيْدِ بْنِ نُضَيْلَةَ الْخُزَاعِيِّ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ ضَرَبَتِ امْرَأَةٌ ضَرَّتَهَا بِعَمُودِ فُسْطَاطٍ وَهِيَ حُبْلَى فَقَتَلَتْهَا - قَالَ - وَإِحْدَاهُمَا لِحْيَانِيَّةٌ - قَالَ - فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم دِيَةَ الْمَقْتُولَةِ عَلَى عَصَبَةِ الْقَاتِلَةِ وَغُرَّةً لِمَا فِي بَطْنِهَا ‏.‏ فَقَالَ رَجُلٌ مِنْ عَصَبَةِ الْقَاتِلَةِ أَنَغْرَمُ دِيَةَ مَنْ لاَ أَكَلَ وَلاَ شَرِبَ وَلاَ اسْتَهَلَّ فَمِثْلُ ذَلِكَ يُطَلُّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَسَجْعٌ كَسَجْعِ الأَعْرَابِ ‏"‏ ‏.‏ قَالَ وَجَعَلَ عَلَيْهِمُ الدِّيَةَ ‏.‏\hadithno{4393}\hadithtrans{Al-Mughira b. Shu'ba reported that a woman struck her co-wife with a tent-pole and she was pregnant and she killed her. One of them belonged to the tribe of Lihyan. Allah's Messenger (ﷺ) made the relatives of the murderer responsible for the payment of blood-wit on her behalf, and fixed a slave or a female slave as the indemnity for what was in her womb. One of the persons amongst the relatives of the murderer said:Should we pay indemnity for one who, neither ate, nor drank, nor made any noise, who was just like a nonentity? Thereupon Allah's Messenger (ﷺ) remarked: He speaks rhymed phrases like the people of the desert. He did impose indemnity upon them}}
\hadithdefcmd{muslim}{4394}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا مُفَضَّلٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عُبَيْدِ بْنِ نُضَيْلَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، ‏.‏ أَنَّ امْرَأَةً، قَتَلَتْ ضَرَّتَهَا بِعَمُودِ فُسْطَاطٍ فَأُتِيَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَضَى عَلَى عَاقِلَتِهَا بِالدِّيَةِ وَكَانَتْ حَامِلاً فَقَضَى فِي الْجَنِينِ بِغُرَّةٍ ‏.‏ فَقَالَ بَعْضُ عَصَبَتِهَا أَنَدِي مَنْ لاَ طَعِمَ وَلاَ شَرِبَ وَلاَ صَاحَ فَاسْتَهَلَّ وَمِثْلُ ذَلِكَ يُطَلُّ قَالَ فَقَالَ ‏ "‏ سَجْعٌ كَسَجْعِ الأَعْرَابِ ‏"‏ ‏.‏\hadithno{4394}\hadithtrans{Al-Mughira b. Shu'ba reported:A woman killed her fellow-wife with a tent-pole. Her case was brought to Allah's Messenger (ﷺ), and he gave judgment that blood-wit should be paid by the relatives (of the offender) on the father's side. And as she was pregnant, he decided regarding her unborn child that a male or a female slave of good quality be given. Some of her offender's) relatives said: Should we make compensation for one who never ate, nor drank, nor made any noise, who was like a nonentity? Thereupon Allah's Messenger (ﷺ) said: He was talking rhymed phrases like the rhymed phrases of desert Arabs}}
\hadithdefcmd{muslim}{4395}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ مِثْلَ مَعْنَى حَدِيثِ جَرِيرٍ وَمُفَضَّلٍ ‏.‏\hadithno{4395}\hadithtrans{This hadith has been narrated on the authority of Mansur with the same chain of transmitters}}
\hadithdefcmd{muslim}{4396}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالُوا حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ عَنْ شُعْبَةَ، عَنْ مَنْصُورٍ، بِإِسْنَادِهِمُ الْحَدِيثَ بِقِصَّتِهِ ‏.‏ غَيْرَ أَنَّ فِيهِ فَأَسْقَطَتْ فَرُفِعَ ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَضَى فِيهِ بِغُرَّةٍ وَجَعَلَهُ عَلَى أَوْلِيَاءِ الْمَرْأَةِ ‏.‏ وَلَمْ يَذْكُرْ فِي الْحَدِيثِ دِيَةَ الْمَرْأَةِ ‏.‏\hadithno{4396}\hadithtrans{Mansur transmitted this hadith with a slight variation of words}}
\hadithdefcmd{muslim}{4397}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ اسْتَشَارَ عُمَرُ بْنُ الْخَطَّابِ النَّاسَ فِي إِمْلاَصِ الْمَرْأَةِ فَقَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ شَهِدْتُ النَّبِيَّ صلى الله عليه وسلم قَضَى فِيهِ بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ ‏.‏ قَالَ فَقَالَ عُمَرُ ائْتِنِي بِمَنْ يَشْهَدُ مَعَكَ قَالَ فَشَهِدَ لَهُ مُحَمَّدُ بْنُ مَسْلَمَةَ ‏.‏\hadithno{4397}\hadithtrans{Miswar b. Makhrama reported that 'Umar b. Khattab consulted people about the diyat of abortion of an unboam child. Mughira b. Shu'ba said:I bear witness to the fact that Allah's Messenger (ﷺ) gave judgment about it that a good quality of slave or female slave should be given for it. Thereupon 'Umar said: Bring one who may bear witness to you. Then Muhammad b. Maslama bore witness to him}}
